---
name: "📝 Documentation"
about: "Report an issue related to the documentation"
title: "[DOC] <issue> with <module.component>"
labels: documentation
assignees: ''

---

### Description

A clear description of what the issue is and where it is in the documentation (*e.g* [ssim.html#piqa.ssim.ssim](https://francois-rozet.github.io/piqa/ssim.html#piqa.ssim.ssim)).

### Expectation

A clear description of what you expected.
